@@ -1,8 +1,9 @@
 import os
-
+from datetime import datetime
 from io import StringIO
 
 from lxml import etree
+
 try:
     import importlib.resources as pkg_resources
 except ImportError:
@@ -20,15 +21,14 @@ class JupyXML:
     def __init__(self, xml_file_or_path: Union[AnyStr, TextIO]):
         self.xml_file_or_path = xml_file_or_path
         if os.path.exists(xml_file_or_path):
-            print("Loading file filename")
             self._file = self.xml_file_or_path
         else:
-            print("Loading from string")
             self._file = StringIO(xml_file_or_path)
         self.root = etree.parse(self._file)
 
     def _repr_html_(self) -> AnyStr:
-        cards = create_recursive_accordian_html(self.root.getroot(), root_identifier="0",
+        root_identifier = str(datetime.now().timestamp()).replace(".", "")
+        cards = create_recursive_accordian_html(self.root.getroot(), root_identifier=root_identifier,
                                                 max_depth=10, current_depth=0)
         css = pkg_resources.read_text(styles, 'jupyxml.css')
         # Concatenate css and cards. TODO: It would be nice if the css was "once-only"
@@ -39,4 +39,4 @@ class JupyXML:
             </style>
             {cards}
         """
-        return html_representation
\ No newline at end of file
+        return html_representation
